# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from neurion.ganglion import tx_pb2 as neurion_dot_ganglion_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in neurion/ganglion/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpdateParams = channel.unary_unary(
                '/neurion.ganglion.Msg/UpdateParams',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)
        self.RegisterIon = channel.unary_unary(
                '/neurion.ganglion.Msg/RegisterIon',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRegisterIon.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRegisterIonResponse.FromString,
                _registered_method=True)
        self.ReportUnavailableIon = channel.unary_unary(
                '/neurion.ganglion.Msg/ReportUnavailableIon',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgReportUnavailableIon.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgReportUnavailableIonResponse.FromString,
                _registered_method=True)
        self.UnreportUnavailableIon = channel.unary_unary(
                '/neurion.ganglion.Msg/UnreportUnavailableIon',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgUnreportUnavailableIon.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgUnreportUnavailableIonResponse.FromString,
                _registered_method=True)
        self.AddValidator = channel.unary_unary(
                '/neurion.ganglion.Msg/AddValidator',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgAddValidator.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgAddValidatorResponse.FromString,
                _registered_method=True)
        self.RemoveValidator = channel.unary_unary(
                '/neurion.ganglion.Msg/RemoveValidator',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemoveValidator.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemoveValidatorResponse.FromString,
                _registered_method=True)
        self.ValidateAvailability = channel.unary_unary(
                '/neurion.ganglion.Msg/ValidateAvailability',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgValidateAvailability.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgValidateAvailabilityResponse.FromString,
                _registered_method=True)
        self.RegisterPathway = channel.unary_unary(
                '/neurion.ganglion.Msg/RegisterPathway',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRegisterPathway.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRegisterPathwayResponse.FromString,
                _registered_method=True)
        self.StakePathway = channel.unary_unary(
                '/neurion.ganglion.Msg/StakePathway',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgStakePathway.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgStakePathwayResponse.FromString,
                _registered_method=True)
        self.RefundPathwayStake = channel.unary_unary(
                '/neurion.ganglion.Msg/RefundPathwayStake',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRefundPathwayStake.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRefundPathwayStakeResponse.FromString,
                _registered_method=True)
        self.InitUnstakePathway = channel.unary_unary(
                '/neurion.ganglion.Msg/InitUnstakePathway',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgInitUnstakePathway.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgInitUnstakePathwayResponse.FromString,
                _registered_method=True)
        self.ClaimProtocolFee = channel.unary_unary(
                '/neurion.ganglion.Msg/ClaimProtocolFee',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgClaimProtocolFee.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgClaimProtocolFeeResponse.FromString,
                _registered_method=True)
        self.SettlePathwayStake = channel.unary_unary(
                '/neurion.ganglion.Msg/SettlePathwayStake',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgSettlePathwayStake.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgSettlePathwayStakeResponse.FromString,
                _registered_method=True)
        self.StakeToGanglion = channel.unary_unary(
                '/neurion.ganglion.Msg/StakeToGanglion',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgStakeToGanglion.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgStakeToGanglionResponse.FromString,
                _registered_method=True)
        self.ClaimReward = channel.unary_unary(
                '/neurion.ganglion.Msg/ClaimReward',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgClaimReward.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgClaimRewardResponse.FromString,
                _registered_method=True)
        self.UnstakeFromGanglion = channel.unary_unary(
                '/neurion.ganglion.Msg/UnstakeFromGanglion',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgUnstakeFromGanglion.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgUnstakeFromGanglionResponse.FromString,
                _registered_method=True)
        self.UpdatePathway = channel.unary_unary(
                '/neurion.ganglion.Msg/UpdatePathway',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgUpdatePathway.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgUpdatePathwayResponse.FromString,
                _registered_method=True)
        self.RemoveIon = channel.unary_unary(
                '/neurion.ganglion.Msg/RemoveIon',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemoveIon.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemoveIonResponse.FromString,
                _registered_method=True)
        self.RemovePathway = channel.unary_unary(
                '/neurion.ganglion.Msg/RemovePathway',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemovePathway.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemovePathwayResponse.FromString,
                _registered_method=True)
        self.SetAllowedIps = channel.unary_unary(
                '/neurion.ganglion.Msg/SetAllowedIps',
                request_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgSetAllowedIps.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgSetAllowedIpsResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def UpdateParams(self, request, context):
        """UpdateParams defines a (governance) operation for updating the module
        parameters. The authority defaults to the x/gov module account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterIon(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportUnavailableIon(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnreportUnavailableIon(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddValidator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveValidator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateAvailability(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterPathway(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StakePathway(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefundPathwayStake(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitUnstakePathway(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClaimProtocolFee(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SettlePathwayStake(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StakeToGanglion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClaimReward(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnstakeFromGanglion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePathway(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveIon(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePathway(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAllowedIps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'RegisterIon': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterIon,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRegisterIon.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRegisterIonResponse.SerializeToString,
            ),
            'ReportUnavailableIon': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportUnavailableIon,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgReportUnavailableIon.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgReportUnavailableIonResponse.SerializeToString,
            ),
            'UnreportUnavailableIon': grpc.unary_unary_rpc_method_handler(
                    servicer.UnreportUnavailableIon,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgUnreportUnavailableIon.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgUnreportUnavailableIonResponse.SerializeToString,
            ),
            'AddValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.AddValidator,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgAddValidator.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgAddValidatorResponse.SerializeToString,
            ),
            'RemoveValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveValidator,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemoveValidator.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemoveValidatorResponse.SerializeToString,
            ),
            'ValidateAvailability': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateAvailability,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgValidateAvailability.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgValidateAvailabilityResponse.SerializeToString,
            ),
            'RegisterPathway': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterPathway,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRegisterPathway.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRegisterPathwayResponse.SerializeToString,
            ),
            'StakePathway': grpc.unary_unary_rpc_method_handler(
                    servicer.StakePathway,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgStakePathway.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgStakePathwayResponse.SerializeToString,
            ),
            'RefundPathwayStake': grpc.unary_unary_rpc_method_handler(
                    servicer.RefundPathwayStake,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRefundPathwayStake.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRefundPathwayStakeResponse.SerializeToString,
            ),
            'InitUnstakePathway': grpc.unary_unary_rpc_method_handler(
                    servicer.InitUnstakePathway,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgInitUnstakePathway.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgInitUnstakePathwayResponse.SerializeToString,
            ),
            'ClaimProtocolFee': grpc.unary_unary_rpc_method_handler(
                    servicer.ClaimProtocolFee,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgClaimProtocolFee.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgClaimProtocolFeeResponse.SerializeToString,
            ),
            'SettlePathwayStake': grpc.unary_unary_rpc_method_handler(
                    servicer.SettlePathwayStake,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgSettlePathwayStake.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgSettlePathwayStakeResponse.SerializeToString,
            ),
            'StakeToGanglion': grpc.unary_unary_rpc_method_handler(
                    servicer.StakeToGanglion,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgStakeToGanglion.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgStakeToGanglionResponse.SerializeToString,
            ),
            'ClaimReward': grpc.unary_unary_rpc_method_handler(
                    servicer.ClaimReward,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgClaimReward.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgClaimRewardResponse.SerializeToString,
            ),
            'UnstakeFromGanglion': grpc.unary_unary_rpc_method_handler(
                    servicer.UnstakeFromGanglion,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgUnstakeFromGanglion.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgUnstakeFromGanglionResponse.SerializeToString,
            ),
            'UpdatePathway': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePathway,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgUpdatePathway.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgUpdatePathwayResponse.SerializeToString,
            ),
            'RemoveIon': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveIon,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemoveIon.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemoveIonResponse.SerializeToString,
            ),
            'RemovePathway': grpc.unary_unary_rpc_method_handler(
                    servicer.RemovePathway,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemovePathway.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgRemovePathwayResponse.SerializeToString,
            ),
            'SetAllowedIps': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAllowedIps,
                    request_deserializer=neurion_dot_ganglion_dot_tx__pb2.MsgSetAllowedIps.FromString,
                    response_serializer=neurion_dot_ganglion_dot_tx__pb2.MsgSetAllowedIpsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'neurion.ganglion.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('neurion.ganglion.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/UpdateParams',
            neurion_dot_ganglion_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterIon(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/RegisterIon',
            neurion_dot_ganglion_dot_tx__pb2.MsgRegisterIon.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgRegisterIonResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReportUnavailableIon(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/ReportUnavailableIon',
            neurion_dot_ganglion_dot_tx__pb2.MsgReportUnavailableIon.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgReportUnavailableIonResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnreportUnavailableIon(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/UnreportUnavailableIon',
            neurion_dot_ganglion_dot_tx__pb2.MsgUnreportUnavailableIon.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgUnreportUnavailableIonResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/AddValidator',
            neurion_dot_ganglion_dot_tx__pb2.MsgAddValidator.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgAddValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/RemoveValidator',
            neurion_dot_ganglion_dot_tx__pb2.MsgRemoveValidator.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgRemoveValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateAvailability(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/ValidateAvailability',
            neurion_dot_ganglion_dot_tx__pb2.MsgValidateAvailability.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgValidateAvailabilityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterPathway(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/RegisterPathway',
            neurion_dot_ganglion_dot_tx__pb2.MsgRegisterPathway.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgRegisterPathwayResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StakePathway(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/StakePathway',
            neurion_dot_ganglion_dot_tx__pb2.MsgStakePathway.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgStakePathwayResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RefundPathwayStake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/RefundPathwayStake',
            neurion_dot_ganglion_dot_tx__pb2.MsgRefundPathwayStake.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgRefundPathwayStakeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InitUnstakePathway(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/InitUnstakePathway',
            neurion_dot_ganglion_dot_tx__pb2.MsgInitUnstakePathway.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgInitUnstakePathwayResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClaimProtocolFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/ClaimProtocolFee',
            neurion_dot_ganglion_dot_tx__pb2.MsgClaimProtocolFee.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgClaimProtocolFeeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SettlePathwayStake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/SettlePathwayStake',
            neurion_dot_ganglion_dot_tx__pb2.MsgSettlePathwayStake.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgSettlePathwayStakeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StakeToGanglion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/StakeToGanglion',
            neurion_dot_ganglion_dot_tx__pb2.MsgStakeToGanglion.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgStakeToGanglionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClaimReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/ClaimReward',
            neurion_dot_ganglion_dot_tx__pb2.MsgClaimReward.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgClaimRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnstakeFromGanglion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/UnstakeFromGanglion',
            neurion_dot_ganglion_dot_tx__pb2.MsgUnstakeFromGanglion.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgUnstakeFromGanglionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdatePathway(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/UpdatePathway',
            neurion_dot_ganglion_dot_tx__pb2.MsgUpdatePathway.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgUpdatePathwayResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveIon(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/RemoveIon',
            neurion_dot_ganglion_dot_tx__pb2.MsgRemoveIon.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgRemoveIonResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemovePathway(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/RemovePathway',
            neurion_dot_ganglion_dot_tx__pb2.MsgRemovePathway.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgRemovePathwayResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetAllowedIps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Msg/SetAllowedIps',
            neurion_dot_ganglion_dot_tx__pb2.MsgSetAllowedIps.SerializeToString,
            neurion_dot_ganglion_dot_tx__pb2.MsgSetAllowedIpsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from abc import ABC, abstractmethod

from neurionpy.protos.cosmos.evidence.v1beta1.query_pb2 import (
    QueryAllEvidenceRequest,
    QueryAllEvidenceResponse,
    QueryEvidenceRequest,
    QueryEvidenceResponse,
)


class Evidence(ABC):
    """Evidence abstract class."""

    @abstractmethod
    def Evidence(self, request: QueryEvidenceRequest) -> QueryEvidenceResponse:
        """
        Evidence queries evidence based on evidence hash.

        :param request: QueryEvidenceRequest

        :return: QueryEvidenceResponse
        """

    @abstractmethod
    def AllEvidence(self, request: QueryAllEvidenceRequest) -> QueryAllEvidenceResponse:
        """
        AllEvidence queries all evidence.

        :param request: QueryAllEvidenceRequest

        :return: QueryAllEvidenceResponse
        """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/types/v2/evidence.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/types/v2/evidence.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.types.v2 import types_pb2 as cometbft_dot_types_dot_v2_dot_types__pb2
from cometbft.types.v2 import validator_pb2 as cometbft_dot_types_dot_v2_dot_validator__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cometbft/types/v2/evidence.proto\x12\x11\x63ometbft.types.v2\x1a\x1d\x63ometbft/types/v2/types.proto\x1a!cometbft/types/v2/validator.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb4\x01\n\x08\x45vidence\x12K\n\x17\x64uplicate_vote_evidence\x18\x01 \x01(\x0b\x32(.cometbft.types.v2.DuplicateVoteEvidenceH\x00\x12T\n\x1clight_client_attack_evidence\x18\x02 \x01(\x0b\x32,.cometbft.types.v2.LightClientAttackEvidenceH\x00\x42\x05\n\x03sum\"\xd7\x01\n\x15\x44uplicateVoteEvidence\x12\'\n\x06vote_a\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v2.Vote\x12\'\n\x06vote_b\x18\x02 \x01(\x0b\x32\x17.cometbft.types.v2.Vote\x12\x1a\n\x12total_voting_power\x18\x03 \x01(\x03\x12\x17\n\x0fvalidator_power\x18\x04 \x01(\x03\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"\xfd\x01\n\x19LightClientAttackEvidence\x12\x38\n\x11\x63onflicting_block\x18\x01 \x01(\x0b\x32\x1d.cometbft.types.v2.LightBlock\x12\x15\n\rcommon_height\x18\x02 \x01(\x03\x12:\n\x14\x62yzantine_validators\x18\x03 \x03(\x0b\x32\x1c.cometbft.types.v2.Validator\x12\x1a\n\x12total_voting_power\x18\x04 \x01(\x03\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"C\n\x0c\x45videnceList\x12\x33\n\x08\x65vidence\x18\x01 \x03(\x0b\x32\x1b.cometbft.types.v2.EvidenceB\x04\xc8\xde\x1f\x00\x42\x34Z2github.com/cometbft/cometbft/api/cometbft/types/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v2.evidence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cometbft/cometbft/api/cometbft/types/v2'
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._loaded_options = None
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCE']._serialized_start=177
  _globals['_EVIDENCE']._serialized_end=357
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_start=360
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_end=575
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_start=578
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_end=831
  _globals['_EVIDENCELIST']._serialized_start=833
  _globals['_EVIDENCELIST']._serialized_end=900
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/types/v1beta1/validator.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/types/v1beta1/validator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cometbft.crypto.v1 import keys_pb2 as cometbft_dot_crypto_dot_v1_dot_keys__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cometbft/types/v1beta1/validator.proto\x12\x16\x63ometbft.types.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1d\x63ometbft/crypto/v1/keys.proto\"\x96\x01\n\x0cValidatorSet\x12\x35\n\nvalidators\x18\x01 \x03(\x0b\x32!.cometbft.types.v1beta1.Validator\x12\x33\n\x08proposer\x18\x02 \x01(\x0b\x32!.cometbft.types.v1beta1.Validator\x12\x1a\n\x12total_voting_power\x18\x03 \x01(\x03\"\x83\x01\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x34\n\x07pub_key\x18\x02 \x01(\x0b\x32\x1d.cometbft.crypto.v1.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x14\n\x0cvoting_power\x18\x03 \x01(\x03\x12\x19\n\x11proposer_priority\x18\x04 \x01(\x03\"W\n\x0fSimpleValidator\x12.\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1d.cometbft.crypto.v1.PublicKey\x12\x14\n\x0cvoting_power\x18\x02 \x01(\x03*\xd7\x01\n\x0b\x42lockIDFlag\x12\x31\n\x15\x42LOCK_ID_FLAG_UNKNOWN\x10\x00\x1a\x16\x8a\x9d \x12\x42lockIDFlagUnknown\x12/\n\x14\x42LOCK_ID_FLAG_ABSENT\x10\x01\x1a\x15\x8a\x9d \x11\x42lockIDFlagAbsent\x12/\n\x14\x42LOCK_ID_FLAG_COMMIT\x10\x02\x1a\x15\x8a\x9d \x11\x42lockIDFlagCommit\x12)\n\x11\x42LOCK_ID_FLAG_NIL\x10\x03\x1a\x12\x8a\x9d \x0e\x42lockIDFlagNil\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x01\x42\x39Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1beta1.validator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta1'
  _globals['_BLOCKIDFLAG']._loaded_options = None
  _globals['_BLOCKIDFLAG']._serialized_options = b'\210\243\036\000\250\244\036\001'
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_UNKNOWN"]._loaded_options = None
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_UNKNOWN"]._serialized_options = b'\212\235 \022BlockIDFlagUnknown'
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_ABSENT"]._loaded_options = None
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_ABSENT"]._serialized_options = b'\212\235 \021BlockIDFlagAbsent'
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_COMMIT"]._loaded_options = None
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_COMMIT"]._serialized_options = b'\212\235 \021BlockIDFlagCommit'
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_NIL"]._loaded_options = None
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_NIL"]._serialized_options = b'\212\235 \016BlockIDFlagNil'
  _globals['_VALIDATOR'].fields_by_name['pub_key']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKIDFLAG']._serialized_start=496
  _globals['_BLOCKIDFLAG']._serialized_end=711
  _globals['_VALIDATORSET']._serialized_start=120
  _globals['_VALIDATORSET']._serialized_end=270
  _globals['_VALIDATOR']._serialized_start=273
  _globals['_VALIDATOR']._serialized_end=404
  _globals['_SIMPLEVALIDATOR']._serialized_start=406
  _globals['_SIMPLEVALIDATOR']._serialized_end=493
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/types/params.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tendermint/types/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtendermint/types/params.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"\xf3\x01\n\x0f\x43onsensusParams\x12\x32\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1d.tendermint.types.BlockParamsB\x04\xc8\xde\x1f\x00\x12\x38\n\x08\x65vidence\x18\x02 \x01(\x0b\x32 .tendermint.types.EvidenceParamsB\x04\xc8\xde\x1f\x00\x12:\n\tvalidator\x18\x03 \x01(\x0b\x32!.tendermint.types.ValidatorParamsB\x04\xc8\xde\x1f\x00\x12\x36\n\x07version\x18\x04 \x01(\x0b\x32\x1f.tendermint.types.VersionParamsB\x04\xc8\xde\x1f\x00\"G\n\x0b\x42lockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03\x12\x14\n\x0ctime_iota_ms\x18\x03 \x01(\x03\"~\n\x0e\x45videnceParams\x12\x1a\n\x12max_age_num_blocks\x18\x01 \x01(\x03\x12=\n\x10max_age_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x11\n\tmax_bytes\x18\x03 \x01(\x03\"2\n\x0fValidatorParams\x12\x15\n\rpub_key_types\x18\x01 \x03(\t:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\".\n\rVersionParams\x12\x13\n\x0b\x61pp_version\x18\x01 \x01(\x04:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\">\n\x0cHashedParams\x12\x17\n\x0f\x62lock_max_bytes\x18\x01 \x01(\x03\x12\x15\n\rblock_max_gas\x18\x02 \x01(\x03\x42=Z7github.com/tendermint/tendermint/proto/tendermint/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types\250\342\036\001'
  _globals['_CONSENSUSPARAMS'].fields_by_name['block']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['block']._serialized_options = b'\310\336\037\000'
  _globals['_CONSENSUSPARAMS'].fields_by_name['evidence']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_CONSENSUSPARAMS'].fields_by_name['validator']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_CONSENSUSPARAMS'].fields_by_name['version']._loaded_options = None
  _globals['_CONSENSUSPARAMS'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._loaded_options = None
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_VALIDATORPARAMS']._loaded_options = None
  _globals['_VALIDATORPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_VERSIONPARAMS']._loaded_options = None
  _globals['_VERSIONPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_CONSENSUSPARAMS']._serialized_start=106
  _globals['_CONSENSUSPARAMS']._serialized_end=349
  _globals['_BLOCKPARAMS']._serialized_start=351
  _globals['_BLOCKPARAMS']._serialized_end=422
  _globals['_EVIDENCEPARAMS']._serialized_start=424
  _globals['_EVIDENCEPARAMS']._serialized_end=550
  _globals['_VALIDATORPARAMS']._serialized_start=552
  _globals['_VALIDATORPARAMS']._serialized_end=602
  _globals['_VERSIONPARAMS']._serialized_start=604
  _globals['_VERSIONPARAMS']._serialized_end=650
  _globals['_HASHEDPARAMS']._serialized_start=652
  _globals['_HASHEDPARAMS']._serialized_end=714
# @@protoc_insertion_point(module_scope)



from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.api import annotations_pb2 as _annotations_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryClientStateRequest(_message.Message):
    __slots__ = ("client_id",)
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    def __init__(self, client_id: _Optional[str] = ...) -> None: ...

class QueryClientStateResponse(_message.Message):
    __slots__ = ("client_state", "proof", "proof_height")
    CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    client_state: _any_pb2.Any
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, client_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryClientStatesRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryClientStatesResponse(_message.Message):
    __slots__ = ("client_states", "pagination")
    CLIENT_STATES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    client_states: _containers.RepeatedCompositeFieldContainer[_client_pb2.IdentifiedClientState]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, client_states: _Optional[_Iterable[_Union[_client_pb2.IdentifiedClientState, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryConsensusStateRequest(_message.Message):
    __slots__ = ("client_id", "revision_number", "revision_height", "latest_height")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    REVISION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    REVISION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LATEST_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    revision_number: int
    revision_height: int
    latest_height: bool
    def __init__(self, client_id: _Optional[str] = ..., revision_number: _Optional[int] = ..., revision_height: _Optional[int] = ..., latest_height: bool = ...) -> None: ...

class QueryConsensusStateResponse(_message.Message):
    __slots__ = ("consensus_state", "proof", "proof_height")
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    consensus_state: _any_pb2.Any
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, consensus_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryConsensusStatesRequest(_message.Message):
    __slots__ = ("client_id", "pagination")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, client_id: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryConsensusStatesResponse(_message.Message):
    __slots__ = ("consensus_states", "pagination")
    CONSENSUS_STATES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    consensus_states: _containers.RepeatedCompositeFieldContainer[_client_pb2.ConsensusStateWithHeight]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, consensus_states: _Optional[_Iterable[_Union[_client_pb2.ConsensusStateWithHeight, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryClientStatusRequest(_message.Message):
    __slots__ = ("client_id",)
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    def __init__(self, client_id: _Optional[str] = ...) -> None: ...

class QueryClientStatusResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: str
    def __init__(self, status: _Optional[str] = ...) -> None: ...

class QueryClientParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryClientParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _client_pb2.Params
    def __init__(self, params: _Optional[_Union[_client_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryUpgradedClientStateRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryUpgradedClientStateResponse(_message.Message):
    __slots__ = ("upgraded_client_state",)
    UPGRADED_CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    upgraded_client_state: _any_pb2.Any
    def __init__(self, upgraded_client_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class QueryUpgradedConsensusStateRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryUpgradedConsensusStateResponse(_message.Message):
    __slots__ = ("upgraded_consensus_state",)
    UPGRADED_CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    upgraded_consensus_state: _any_pb2.Any
    def __init__(self, upgraded_consensus_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/lightclients/localhost/v1/localhost.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/lightclients/localhost/v1/localhost.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ibc/lightclients/localhost/v1/localhost.proto\x12\x1dibc.lightclients.localhost.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\"l\n\x0b\x43lientState\x12%\n\x08\x63hain_id\x18\x01 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"chain_id\"\x12\x30\n\x06height\x18\x02 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\x42\x46ZDgithub.com/cosmos/ibc-go/v2/modules/light-clients/09-localhost/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.localhost.v1.localhost_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZDgithub.com/cosmos/ibc-go/v2/modules/light-clients/09-localhost/types'
  _globals['_CLIENTSTATE'].fields_by_name['chain_id']._loaded_options = None
  _globals['_CLIENTSTATE'].fields_by_name['chain_id']._serialized_options = b'\362\336\037\017yaml:\"chain_id\"'
  _globals['_CLIENTSTATE'].fields_by_name['height']._loaded_options = None
  _globals['_CLIENTSTATE'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_CLIENTSTATE']._loaded_options = None
  _globals['_CLIENTSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_CLIENTSTATE']._serialized_start=135
  _globals['_CLIENTSTATE']._serialized_end=243
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ScoreTask(_message.Message):
    __slots__ = ("id", "task_id", "submission_id", "result_to_check", "metainfo", "scorer", "created_timestamp", "score", "score_timestamp", "task_kit")
    ID_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_TO_CHECK_FIELD_NUMBER: _ClassVar[int]
    METAINFO_FIELD_NUMBER: _ClassVar[int]
    SCORER_FIELD_NUMBER: _ClassVar[int]
    CREATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    SCORE_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TASK_KIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    task_id: int
    submission_id: int
    result_to_check: str
    metainfo: str
    scorer: str
    created_timestamp: int
    score: str
    score_timestamp: int
    task_kit: str
    def __init__(self, id: _Optional[int] = ..., task_id: _Optional[int] = ..., submission_id: _Optional[int] = ..., result_to_check: _Optional[str] = ..., metainfo: _Optional[str] = ..., scorer: _Optional[str] = ..., created_timestamp: _Optional[int] = ..., score: _Optional[str] = ..., score_timestamp: _Optional[int] = ..., task_kit: _Optional[str] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgTransfer(_message.Message):
    __slots__ = ("source_port", "source_channel", "token", "sender", "receiver", "timeout_height", "timeout_timestamp")
    SOURCE_PORT_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    source_port: str
    source_channel: str
    token: _coin_pb2.Coin
    sender: str
    receiver: str
    timeout_height: _client_pb2.Height
    timeout_timestamp: int
    def __init__(self, source_port: _Optional[str] = ..., source_channel: _Optional[str] = ..., token: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ..., sender: _Optional[str] = ..., receiver: _Optional[str] = ..., timeout_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., timeout_timestamp: _Optional[int] = ...) -> None: ...

class MsgTransferResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmwasm.wasm.v1 import types_pb2 as _types_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StoreCodeProposal(_message.Message):
    __slots__ = ("title", "description", "run_as", "wasm_byte_code", "instantiate_permission")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RUN_AS_FIELD_NUMBER: _ClassVar[int]
    WASM_BYTE_CODE_FIELD_NUMBER: _ClassVar[int]
    INSTANTIATE_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    run_as: str
    wasm_byte_code: bytes
    instantiate_permission: _types_pb2.AccessConfig
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., run_as: _Optional[str] = ..., wasm_byte_code: _Optional[bytes] = ..., instantiate_permission: _Optional[_Union[_types_pb2.AccessConfig, _Mapping]] = ...) -> None: ...

class InstantiateContractProposal(_message.Message):
    __slots__ = ("title", "description", "run_as", "admin", "code_id", "label", "msg", "funds")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RUN_AS_FIELD_NUMBER: _ClassVar[int]
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    FUNDS_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    run_as: str
    admin: str
    code_id: int
    label: str
    msg: bytes
    funds: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., run_as: _Optional[str] = ..., admin: _Optional[str] = ..., code_id: _Optional[int] = ..., label: _Optional[str] = ..., msg: _Optional[bytes] = ..., funds: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class MigrateContractProposal(_message.Message):
    __slots__ = ("title", "description", "contract", "code_id", "msg")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    contract: str
    code_id: int
    msg: bytes
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., contract: _Optional[str] = ..., code_id: _Optional[int] = ..., msg: _Optional[bytes] = ...) -> None: ...

class SudoContractProposal(_message.Message):
    __slots__ = ("title", "description", "contract", "msg")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    contract: str
    msg: bytes
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., contract: _Optional[str] = ..., msg: _Optional[bytes] = ...) -> None: ...

class ExecuteContractProposal(_message.Message):
    __slots__ = ("title", "description", "run_as", "contract", "msg", "funds")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RUN_AS_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    FUNDS_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    run_as: str
    contract: str
    msg: bytes
    funds: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., run_as: _Optional[str] = ..., contract: _Optional[str] = ..., msg: _Optional[bytes] = ..., funds: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class UpdateAdminProposal(_message.Message):
    __slots__ = ("title", "description", "new_admin", "contract")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    NEW_ADMIN_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    new_admin: str
    contract: str
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., new_admin: _Optional[str] = ..., contract: _Optional[str] = ...) -> None: ...

class ClearAdminProposal(_message.Message):
    __slots__ = ("title", "description", "contract")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    contract: str
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., contract: _Optional[str] = ...) -> None: ...

class PinCodesProposal(_message.Message):
    __slots__ = ("title", "description", "code_ids")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_IDS_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    code_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., code_ids: _Optional[_Iterable[int]] = ...) -> None: ...

class UnpinCodesProposal(_message.Message):
    __slots__ = ("title", "description", "code_ids")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_IDS_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    code_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., code_ids: _Optional[_Iterable[int]] = ...) -> None: ...

class AccessConfigUpdate(_message.Message):
    __slots__ = ("code_id", "instantiate_permission")
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    INSTANTIATE_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    code_id: int
    instantiate_permission: _types_pb2.AccessConfig
    def __init__(self, code_id: _Optional[int] = ..., instantiate_permission: _Optional[_Union[_types_pb2.AccessConfig, _Mapping]] = ...) -> None: ...

class UpdateInstantiateConfigProposal(_message.Message):
    __slots__ = ("title", "description", "access_config_updates")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ACCESS_CONFIG_UPDATES_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    access_config_updates: _containers.RepeatedCompositeFieldContainer[AccessConfigUpdate]
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., access_config_updates: _Optional[_Iterable[_Union[AccessConfigUpdate, _Mapping]]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from ibc.core.connection.v1 import connection_pb2 as _connection_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgConnectionOpenInit(_message.Message):
    __slots__ = ("client_id", "counterparty", "version", "delay_period", "signer")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    DELAY_PERIOD_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    counterparty: _connection_pb2.Counterparty
    version: _connection_pb2.Version
    delay_period: int
    signer: str
    def __init__(self, client_id: _Optional[str] = ..., counterparty: _Optional[_Union[_connection_pb2.Counterparty, _Mapping]] = ..., version: _Optional[_Union[_connection_pb2.Version, _Mapping]] = ..., delay_period: _Optional[int] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgConnectionOpenInitResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgConnectionOpenTry(_message.Message):
    __slots__ = ("client_id", "previous_connection_id", "client_state", "counterparty", "delay_period", "counterparty_versions", "proof_height", "proof_init", "proof_client", "proof_consensus", "consensus_height", "signer")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    PREVIOUS_CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    DELAY_PERIOD_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_VERSIONS_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PROOF_INIT_FIELD_NUMBER: _ClassVar[int]
    PROOF_CLIENT_FIELD_NUMBER: _ClassVar[int]
    PROOF_CONSENSUS_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    previous_connection_id: str
    client_state: _any_pb2.Any
    counterparty: _connection_pb2.Counterparty
    delay_period: int
    counterparty_versions: _containers.RepeatedCompositeFieldContainer[_connection_pb2.Version]
    proof_height: _client_pb2.Height
    proof_init: bytes
    proof_client: bytes
    proof_consensus: bytes
    consensus_height: _client_pb2.Height
    signer: str
    def __init__(self, client_id: _Optional[str] = ..., previous_connection_id: _Optional[str] = ..., client_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., counterparty: _Optional[_Union[_connection_pb2.Counterparty, _Mapping]] = ..., delay_period: _Optional[int] = ..., counterparty_versions: _Optional[_Iterable[_Union[_connection_pb2.Version, _Mapping]]] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., proof_init: _Optional[bytes] = ..., proof_client: _Optional[bytes] = ..., proof_consensus: _Optional[bytes] = ..., consensus_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgConnectionOpenTryResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgConnectionOpenAck(_message.Message):
    __slots__ = ("connection_id", "counterparty_connection_id", "version", "client_state", "proof_height", "proof_try", "proof_client", "proof_consensus", "consensus_height", "signer")
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PROOF_TRY_FIELD_NUMBER: _ClassVar[int]
    PROOF_CLIENT_FIELD_NUMBER: _ClassVar[int]
    PROOF_CONSENSUS_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    counterparty_connection_id: str
    version: _connection_pb2.Version
    client_state: _any_pb2.Any
    proof_height: _client_pb2.Height
    proof_try: bytes
    proof_client: bytes
    proof_consensus: bytes
    consensus_height: _client_pb2.Height
    signer: str
    def __init__(self, connection_id: _Optional[str] = ..., counterparty_connection_id: _Optional[str] = ..., version: _Optional[_Union[_connection_pb2.Version, _Mapping]] = ..., client_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., proof_try: _Optional[bytes] = ..., proof_client: _Optional[bytes] = ..., proof_consensus: _Optional[bytes] = ..., consensus_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgConnectionOpenAckResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgConnectionOpenConfirm(_message.Message):
    __slots__ = ("connection_id", "proof_ack", "proof_height", "signer")
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PROOF_ACK_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    proof_ack: bytes
    proof_height: _client_pb2.Height
    signer: str
    def __init__(self, connection_id: _Optional[str] = ..., proof_ack: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ..., signer: _Optional[str] = ...) -> None: ...

class MsgConnectionOpenConfirmResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from cosmos.upgrade.v1beta1 import upgrade_pb2 as _upgrade_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IdentifiedClientState(_message.Message):
    __slots__ = ("client_id", "client_state")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_state: _any_pb2.Any
    def __init__(self, client_id: _Optional[str] = ..., client_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class ConsensusStateWithHeight(_message.Message):
    __slots__ = ("height", "consensus_state")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    height: Height
    consensus_state: _any_pb2.Any
    def __init__(self, height: _Optional[_Union[Height, _Mapping]] = ..., consensus_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class ClientConsensusStates(_message.Message):
    __slots__ = ("client_id", "consensus_states")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_STATES_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    consensus_states: _containers.RepeatedCompositeFieldContainer[ConsensusStateWithHeight]
    def __init__(self, client_id: _Optional[str] = ..., consensus_states: _Optional[_Iterable[_Union[ConsensusStateWithHeight, _Mapping]]] = ...) -> None: ...

class ClientUpdateProposal(_message.Message):
    __slots__ = ("title", "description", "subject_client_id", "substitute_client_id")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    SUBSTITUTE_CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    subject_client_id: str
    substitute_client_id: str
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., subject_client_id: _Optional[str] = ..., substitute_client_id: _Optional[str] = ...) -> None: ...

class UpgradeProposal(_message.Message):
    __slots__ = ("title", "description", "plan", "upgraded_client_state")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    UPGRADED_CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    plan: _upgrade_pb2.Plan
    upgraded_client_state: _any_pb2.Any
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., plan: _Optional[_Union[_upgrade_pb2.Plan, _Mapping]] = ..., upgraded_client_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class Height(_message.Message):
    __slots__ = ("revision_number", "revision_height")
    REVISION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    REVISION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    revision_number: int
    revision_height: int
    def __init__(self, revision_number: _Optional[int] = ..., revision_height: _Optional[int] = ...) -> None: ...

class Params(_message.Message):
    __slots__ = ("allowed_clients",)
    ALLOWED_CLIENTS_FIELD_NUMBER: _ClassVar[int]
    allowed_clients: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, allowed_clients: _Optional[_Iterable[str]] = ...) -> None: ...



from ibc.core.client.v1 import client_pb2 as _client_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from ibc.core.channel.v1 import channel_pb2 as _channel_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import any_pb2 as _any_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryChannelRequest(_message.Message):
    __slots__ = ("port_id", "channel_id")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...

class QueryChannelResponse(_message.Message):
    __slots__ = ("channel", "proof", "proof_height")
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    channel: _channel_pb2.Channel
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, channel: _Optional[_Union[_channel_pb2.Channel, _Mapping]] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryChannelsRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryChannelsResponse(_message.Message):
    __slots__ = ("channels", "pagination", "height")
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    channels: _containers.RepeatedCompositeFieldContainer[_channel_pb2.IdentifiedChannel]
    pagination: _pagination_pb2.PageResponse
    height: _client_pb2.Height
    def __init__(self, channels: _Optional[_Iterable[_Union[_channel_pb2.IdentifiedChannel, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ..., height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryConnectionChannelsRequest(_message.Message):
    __slots__ = ("connection", "pagination")
    CONNECTION_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    connection: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, connection: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryConnectionChannelsResponse(_message.Message):
    __slots__ = ("channels", "pagination", "height")
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    channels: _containers.RepeatedCompositeFieldContainer[_channel_pb2.IdentifiedChannel]
    pagination: _pagination_pb2.PageResponse
    height: _client_pb2.Height
    def __init__(self, channels: _Optional[_Iterable[_Union[_channel_pb2.IdentifiedChannel, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ..., height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryChannelClientStateRequest(_message.Message):
    __slots__ = ("port_id", "channel_id")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...

class QueryChannelClientStateResponse(_message.Message):
    __slots__ = ("identified_client_state", "proof", "proof_height")
    IDENTIFIED_CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    identified_client_state: _client_pb2.IdentifiedClientState
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, identified_client_state: _Optional[_Union[_client_pb2.IdentifiedClientState, _Mapping]] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryChannelConsensusStateRequest(_message.Message):
    __slots__ = ("port_id", "channel_id", "revision_number", "revision_height")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    REVISION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    REVISION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    revision_number: int
    revision_height: int
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., revision_number: _Optional[int] = ..., revision_height: _Optional[int] = ...) -> None: ...

class QueryChannelConsensusStateResponse(_message.Message):
    __slots__ = ("consensus_state", "client_id", "proof", "proof_height")
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    consensus_state: _any_pb2.Any
    client_id: str
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, consensus_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., client_id: _Optional[str] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryPacketCommitmentRequest(_message.Message):
    __slots__ = ("port_id", "channel_id", "sequence")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    sequence: int
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., sequence: _Optional[int] = ...) -> None: ...

class QueryPacketCommitmentResponse(_message.Message):
    __slots__ = ("commitment", "proof", "proof_height")
    COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    commitment: bytes
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, commitment: _Optional[bytes] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryPacketCommitmentsRequest(_message.Message):
    __slots__ = ("port_id", "channel_id", "pagination")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryPacketCommitmentsResponse(_message.Message):
    __slots__ = ("commitments", "pagination", "height")
    COMMITMENTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    commitments: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    pagination: _pagination_pb2.PageResponse
    height: _client_pb2.Height
    def __init__(self, commitments: _Optional[_Iterable[_Union[_channel_pb2.PacketState, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ..., height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryPacketReceiptRequest(_message.Message):
    __slots__ = ("port_id", "channel_id", "sequence")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    sequence: int
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., sequence: _Optional[int] = ...) -> None: ...

class QueryPacketReceiptResponse(_message.Message):
    __slots__ = ("received", "proof", "proof_height")
    RECEIVED_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    received: bool
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, received: bool = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryPacketAcknowledgementRequest(_message.Message):
    __slots__ = ("port_id", "channel_id", "sequence")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    sequence: int
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., sequence: _Optional[int] = ...) -> None: ...

class QueryPacketAcknowledgementResponse(_message.Message):
    __slots__ = ("acknowledgement", "proof", "proof_height")
    ACKNOWLEDGEMENT_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    acknowledgement: bytes
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, acknowledgement: _Optional[bytes] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryPacketAcknowledgementsRequest(_message.Message):
    __slots__ = ("port_id", "channel_id", "pagination", "packet_commitment_sequences")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PACKET_COMMITMENT_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    pagination: _pagination_pb2.PageRequest
    packet_commitment_sequences: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ..., packet_commitment_sequences: _Optional[_Iterable[int]] = ...) -> None: ...

class QueryPacketAcknowledgementsResponse(_message.Message):
    __slots__ = ("acknowledgements", "pagination", "height")
    ACKNOWLEDGEMENTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    acknowledgements: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    pagination: _pagination_pb2.PageResponse
    height: _client_pb2.Height
    def __init__(self, acknowledgements: _Optional[_Iterable[_Union[_channel_pb2.PacketState, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ..., height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryUnreceivedPacketsRequest(_message.Message):
    __slots__ = ("port_id", "channel_id", "packet_commitment_sequences")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PACKET_COMMITMENT_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    packet_commitment_sequences: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., packet_commitment_sequences: _Optional[_Iterable[int]] = ...) -> None: ...

class QueryUnreceivedPacketsResponse(_message.Message):
    __slots__ = ("sequences", "height")
    SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    sequences: _containers.RepeatedScalarFieldContainer[int]
    height: _client_pb2.Height
    def __init__(self, sequences: _Optional[_Iterable[int]] = ..., height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryUnreceivedAcksRequest(_message.Message):
    __slots__ = ("port_id", "channel_id", "packet_ack_sequences")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PACKET_ACK_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    packet_ack_sequences: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ..., packet_ack_sequences: _Optional[_Iterable[int]] = ...) -> None: ...

class QueryUnreceivedAcksResponse(_message.Message):
    __slots__ = ("sequences", "height")
    SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    sequences: _containers.RepeatedScalarFieldContainer[int]
    height: _client_pb2.Height
    def __init__(self, sequences: _Optional[_Iterable[int]] = ..., height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...

class QueryNextSequenceReceiveRequest(_message.Message):
    __slots__ = ("port_id", "channel_id")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    channel_id: str
    def __init__(self, port_id: _Optional[str] = ..., channel_id: _Optional[str] = ...) -> None: ...

class QueryNextSequenceReceiveResponse(_message.Message):
    __slots__ = ("next_sequence_receive", "proof", "proof_height")
    NEXT_SEQUENCE_RECEIVE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    next_sequence_receive: int
    proof: bytes
    proof_height: _client_pb2.Height
    def __init__(self, next_sequence_receive: _Optional[int] = ..., proof: _Optional[bytes] = ..., proof_height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/services/pruning/v1/service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/services/pruning/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.services.pruning.v1 import pruning_pb2 as cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/pruning/v1/service.proto\x12\x1c\x63ometbft.services.pruning.v1\x1a*cometbft/services/pruning/v1/pruning.proto2\xfc\t\n\x0ePruningService\x12\x8d\x01\n\x14SetBlockRetainHeight\x12\x39.cometbft.services.pruning.v1.SetBlockRetainHeightRequest\x1a:.cometbft.services.pruning.v1.SetBlockRetainHeightResponse\x12\x8d\x01\n\x14GetBlockRetainHeight\x12\x39.cometbft.services.pruning.v1.GetBlockRetainHeightRequest\x1a:.cometbft.services.pruning.v1.GetBlockRetainHeightResponse\x12\xa2\x01\n\x1bSetBlockResultsRetainHeight\x12@.cometbft.services.pruning.v1.SetBlockResultsRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.SetBlockResultsRetainHeightResponse\x12\xa2\x01\n\x1bGetBlockResultsRetainHeight\x12@.cometbft.services.pruning.v1.GetBlockResultsRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.GetBlockResultsRetainHeightResponse\x12\x99\x01\n\x18SetTxIndexerRetainHeight\x12=.cometbft.services.pruning.v1.SetTxIndexerRetainHeightRequest\x1a>.cometbft.services.pruning.v1.SetTxIndexerRetainHeightResponse\x12\x99\x01\n\x18GetTxIndexerRetainHeight\x12=.cometbft.services.pruning.v1.GetTxIndexerRetainHeightRequest\x1a>.cometbft.services.pruning.v1.GetTxIndexerRetainHeightResponse\x12\xa2\x01\n\x1bSetBlockIndexerRetainHeight\x12@.cometbft.services.pruning.v1.SetBlockIndexerRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.SetBlockIndexerRetainHeightResponse\x12\xa2\x01\n\x1bGetBlockIndexerRetainHeight\x12@.cometbft.services.pruning.v1.GetBlockIndexerRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.GetBlockIndexerRetainHeightResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.pruning.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PRUNINGSERVICE']._serialized_start=121
  _globals['_PRUNINGSERVICE']._serialized_end=1397
# @@protoc_insertion_point(module_scope)



from amino import amino_pb2 as _amino_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("admin_address", "min_task_reward", "min_task_proposer_stake", "min_task_validator_stake", "min_proposal_duration_in_seconds", "min_dispute_duration_in_seconds", "min_creator_stake", "creator_application_fee", "dispute_validator_reward", "min_dispute_score_deposit", "first_proposer_weight", "second_proposer_weight", "third_proposer_weight", "proposer_reward_percentage", "validator_reward_percentage", "staker_reward_percentage")
    ADMIN_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_REWARD_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_PROPOSER_STAKE_FIELD_NUMBER: _ClassVar[int]
    MIN_TASK_VALIDATOR_STAKE_FIELD_NUMBER: _ClassVar[int]
    MIN_PROPOSAL_DURATION_IN_SECONDS_FIELD_NUMBER: _ClassVar[int]
    MIN_DISPUTE_DURATION_IN_SECONDS_FIELD_NUMBER: _ClassVar[int]
    MIN_CREATOR_STAKE_FIELD_NUMBER: _ClassVar[int]
    CREATOR_APPLICATION_FEE_FIELD_NUMBER: _ClassVar[int]
    DISPUTE_VALIDATOR_REWARD_FIELD_NUMBER: _ClassVar[int]
    MIN_DISPUTE_SCORE_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    FIRST_PROPOSER_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    SECOND_PROPOSER_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    THIRD_PROPOSER_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    STAKER_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    admin_address: str
    min_task_reward: int
    min_task_proposer_stake: int
    min_task_validator_stake: int
    min_proposal_duration_in_seconds: int
    min_dispute_duration_in_seconds: int
    min_creator_stake: int
    creator_application_fee: int
    dispute_validator_reward: int
    min_dispute_score_deposit: int
    first_proposer_weight: int
    second_proposer_weight: int
    third_proposer_weight: int
    proposer_reward_percentage: int
    validator_reward_percentage: int
    staker_reward_percentage: int
    def __init__(self, admin_address: _Optional[str] = ..., min_task_reward: _Optional[int] = ..., min_task_proposer_stake: _Optional[int] = ..., min_task_validator_stake: _Optional[int] = ..., min_proposal_duration_in_seconds: _Optional[int] = ..., min_dispute_duration_in_seconds: _Optional[int] = ..., min_creator_stake: _Optional[int] = ..., creator_application_fee: _Optional[int] = ..., dispute_validator_reward: _Optional[int] = ..., min_dispute_score_deposit: _Optional[int] = ..., first_proposer_weight: _Optional[int] = ..., second_proposer_weight: _Optional[int] = ..., third_proposer_weight: _Optional[int] = ..., proposer_reward_percentage: _Optional[int] = ..., validator_reward_percentage: _Optional[int] = ..., staker_reward_percentage: _Optional[int] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConsensusParams(_message.Message):
    __slots__ = ("block", "evidence", "validator", "version")
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    block: BlockParams
    evidence: EvidenceParams
    validator: ValidatorParams
    version: VersionParams
    def __init__(self, block: _Optional[_Union[BlockParams, _Mapping]] = ..., evidence: _Optional[_Union[EvidenceParams, _Mapping]] = ..., validator: _Optional[_Union[ValidatorParams, _Mapping]] = ..., version: _Optional[_Union[VersionParams, _Mapping]] = ...) -> None: ...

class BlockParams(_message.Message):
    __slots__ = ("max_bytes", "max_gas", "time_iota_ms")
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    MAX_GAS_FIELD_NUMBER: _ClassVar[int]
    TIME_IOTA_MS_FIELD_NUMBER: _ClassVar[int]
    max_bytes: int
    max_gas: int
    time_iota_ms: int
    def __init__(self, max_bytes: _Optional[int] = ..., max_gas: _Optional[int] = ..., time_iota_ms: _Optional[int] = ...) -> None: ...

class EvidenceParams(_message.Message):
    __slots__ = ("max_age_num_blocks", "max_age_duration", "max_bytes")
    MAX_AGE_NUM_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    MAX_AGE_DURATION_FIELD_NUMBER: _ClassVar[int]
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    max_age_num_blocks: int
    max_age_duration: _duration_pb2.Duration
    max_bytes: int
    def __init__(self, max_age_num_blocks: _Optional[int] = ..., max_age_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., max_bytes: _Optional[int] = ...) -> None: ...

class ValidatorParams(_message.Message):
    __slots__ = ("pub_key_types",)
    PUB_KEY_TYPES_FIELD_NUMBER: _ClassVar[int]
    pub_key_types: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, pub_key_types: _Optional[_Iterable[str]] = ...) -> None: ...

class VersionParams(_message.Message):
    __slots__ = ("app_version",)
    APP_VERSION_FIELD_NUMBER: _ClassVar[int]
    app_version: int
    def __init__(self, app_version: _Optional[int] = ...) -> None: ...

class HashedParams(_message.Message):
    __slots__ = ("block_max_bytes", "block_max_gas")
    BLOCK_MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    BLOCK_MAX_GAS_FIELD_NUMBER: _ClassVar[int]
    block_max_bytes: int
    block_max_gas: int
    def __init__(self, block_max_bytes: _Optional[int] = ..., block_max_gas: _Optional[int] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from ibc.core.client.v1 import tx_pb2 as ibc_dot_core_dot_client_dot_v1_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in ibc/core/client/v1/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MsgStub(object):
    """Msg defines the ibc/client Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateClient = channel.unary_unary(
                '/ibc.core.client.v1.Msg/CreateClient',
                request_serializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgCreateClient.SerializeToString,
                response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgCreateClientResponse.FromString,
                _registered_method=True)
        self.UpdateClient = channel.unary_unary(
                '/ibc.core.client.v1.Msg/UpdateClient',
                request_serializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpdateClient.SerializeToString,
                response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpdateClientResponse.FromString,
                _registered_method=True)
        self.UpgradeClient = channel.unary_unary(
                '/ibc.core.client.v1.Msg/UpgradeClient',
                request_serializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpgradeClient.SerializeToString,
                response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpgradeClientResponse.FromString,
                _registered_method=True)
        self.SubmitMisbehaviour = channel.unary_unary(
                '/ibc.core.client.v1.Msg/SubmitMisbehaviour',
                request_serializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgSubmitMisbehaviour.SerializeToString,
                response_deserializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgSubmitMisbehaviourResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the ibc/client Msg service.
    """

    def CreateClient(self, request, context):
        """CreateClient defines a rpc handler method for MsgCreateClient.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateClient(self, request, context):
        """UpdateClient defines a rpc handler method for MsgUpdateClient.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpgradeClient(self, request, context):
        """UpgradeClient defines a rpc handler method for MsgUpgradeClient.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitMisbehaviour(self, request, context):
        """SubmitMisbehaviour defines a rpc handler method for MsgSubmitMisbehaviour.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateClient': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateClient,
                    request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgCreateClient.FromString,
                    response_serializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgCreateClientResponse.SerializeToString,
            ),
            'UpdateClient': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateClient,
                    request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpdateClient.FromString,
                    response_serializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpdateClientResponse.SerializeToString,
            ),
            'UpgradeClient': grpc.unary_unary_rpc_method_handler(
                    servicer.UpgradeClient,
                    request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpgradeClient.FromString,
                    response_serializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpgradeClientResponse.SerializeToString,
            ),
            'SubmitMisbehaviour': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitMisbehaviour,
                    request_deserializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgSubmitMisbehaviour.FromString,
                    response_serializer=ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgSubmitMisbehaviourResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.core.client.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ibc.core.client.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the ibc/client Msg service.
    """

    @staticmethod
    def CreateClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.client.v1.Msg/CreateClient',
            ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgCreateClient.SerializeToString,
            ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgCreateClientResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.client.v1.Msg/UpdateClient',
            ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpdateClient.SerializeToString,
            ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpdateClientResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpgradeClient(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.client.v1.Msg/UpgradeClient',
            ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpgradeClient.SerializeToString,
            ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgUpgradeClientResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubmitMisbehaviour(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.client.v1.Msg/SubmitMisbehaviour',
            ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgSubmitMisbehaviour.SerializeToString,
            ibc_dot_core_dot_client_dot_v1_dot_tx__pb2.MsgSubmitMisbehaviourResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from cometbft.crypto.v1 import keys_pb2 as _keys_pb2
from cometbft.types.v1beta1 import types_pb2 as _types_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Errors(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ERRORS_UNKNOWN: _ClassVar[Errors]
    ERRORS_UNEXPECTED_RESPONSE: _ClassVar[Errors]
    ERRORS_NO_CONNECTION: _ClassVar[Errors]
    ERRORS_CONNECTION_TIMEOUT: _ClassVar[Errors]
    ERRORS_READ_TIMEOUT: _ClassVar[Errors]
    ERRORS_WRITE_TIMEOUT: _ClassVar[Errors]
ERRORS_UNKNOWN: Errors
ERRORS_UNEXPECTED_RESPONSE: Errors
ERRORS_NO_CONNECTION: Errors
ERRORS_CONNECTION_TIMEOUT: Errors
ERRORS_READ_TIMEOUT: Errors
ERRORS_WRITE_TIMEOUT: Errors

class RemoteSignerError(_message.Message):
    __slots__ = ("code", "description")
    CODE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    code: int
    description: str
    def __init__(self, code: _Optional[int] = ..., description: _Optional[str] = ...) -> None: ...

class PubKeyRequest(_message.Message):
    __slots__ = ("chain_id",)
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    chain_id: str
    def __init__(self, chain_id: _Optional[str] = ...) -> None: ...

class PubKeyResponse(_message.Message):
    __slots__ = ("pub_key", "error")
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    pub_key: _keys_pb2.PublicKey
    error: RemoteSignerError
    def __init__(self, pub_key: _Optional[_Union[_keys_pb2.PublicKey, _Mapping]] = ..., error: _Optional[_Union[RemoteSignerError, _Mapping]] = ...) -> None: ...

class SignVoteRequest(_message.Message):
    __slots__ = ("vote", "chain_id")
    VOTE_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    vote: _types_pb2.Vote
    chain_id: str
    def __init__(self, vote: _Optional[_Union[_types_pb2.Vote, _Mapping]] = ..., chain_id: _Optional[str] = ...) -> None: ...

class SignedVoteResponse(_message.Message):
    __slots__ = ("vote", "error")
    VOTE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    vote: _types_pb2.Vote
    error: RemoteSignerError
    def __init__(self, vote: _Optional[_Union[_types_pb2.Vote, _Mapping]] = ..., error: _Optional[_Union[RemoteSignerError, _Mapping]] = ...) -> None: ...

class SignProposalRequest(_message.Message):
    __slots__ = ("proposal", "chain_id")
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    proposal: _types_pb2.Proposal
    chain_id: str
    def __init__(self, proposal: _Optional[_Union[_types_pb2.Proposal, _Mapping]] = ..., chain_id: _Optional[str] = ...) -> None: ...

class SignedProposalResponse(_message.Message):
    __slots__ = ("proposal", "error")
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    proposal: _types_pb2.Proposal
    error: RemoteSignerError
    def __init__(self, proposal: _Optional[_Union[_types_pb2.Proposal, _Mapping]] = ..., error: _Optional[_Union[RemoteSignerError, _Mapping]] = ...) -> None: ...

class PingRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PingResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class Message(_message.Message):
    __slots__ = ("pub_key_request", "pub_key_response", "sign_vote_request", "signed_vote_response", "sign_proposal_request", "signed_proposal_response", "ping_request", "ping_response")
    PUB_KEY_REQUEST_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    SIGN_VOTE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    SIGNED_VOTE_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    SIGN_PROPOSAL_REQUEST_FIELD_NUMBER: _ClassVar[int]
    SIGNED_PROPOSAL_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    PING_REQUEST_FIELD_NUMBER: _ClassVar[int]
    PING_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    pub_key_request: PubKeyRequest
    pub_key_response: PubKeyResponse
    sign_vote_request: SignVoteRequest
    signed_vote_response: SignedVoteResponse
    sign_proposal_request: SignProposalRequest
    signed_proposal_response: SignedProposalResponse
    ping_request: PingRequest
    ping_response: PingResponse
    def __init__(self, pub_key_request: _Optional[_Union[PubKeyRequest, _Mapping]] = ..., pub_key_response: _Optional[_Union[PubKeyResponse, _Mapping]] = ..., sign_vote_request: _Optional[_Union[SignVoteRequest, _Mapping]] = ..., signed_vote_response: _Optional[_Union[SignedVoteResponse, _Mapping]] = ..., sign_proposal_request: _Optional[_Union[SignProposalRequest, _Mapping]] = ..., signed_proposal_response: _Optional[_Union[SignedProposalResponse, _Mapping]] = ..., ping_request: _Optional[_Union[PingRequest, _Mapping]] = ..., ping_response: _Optional[_Union[PingResponse, _Mapping]] = ...) -> None: ...



import json
import os
from collections import UserString
from datetime import datetime
from typing import Any, Dict, Optional

from jsonschema import validate

from neurionpy.synapse.client import NeurionClient, prepare_and_broadcast_basic_transaction
from neurionpy.synapse.contract.cosmwasm import (
    create_cosmwasm_clear_admin_msg,
    create_cosmwasm_execute_msg,
    create_cosmwasm_instantiate_msg,
    create_cosmwasm_migrate_msg,
    create_cosmwasm_store_code_msg,
    create_cosmwasm_update_admin_msg,
)
from neurionpy.synapse.tx import Transaction
from neurionpy.synapse.tx_helpers import SubmittedTx
from neurionpy.synapse.wallet import Wallet
from neurionpy.common.utils import json_encode
from neurionpy.crypto.address import Address
from neurionpy.crypto.hashfuncs import sha256
from neurionpy.protos.cosmos.base.query.v1beta1.pagination_pb2 import PageRequest
from neurionpy.protos.cosmwasm.wasm.v1.query_pb2 import (
    QueryCodesRequest,
    QuerySmartContractStateRequest,
)


def _compute_digest(path: str) -> bytes:
    with open(path, "rb") as input_file:
        return sha256(input_file.read())


def _generate_label(digest: bytes) -> str:
    now = datetime.utcnow()
    return f"{digest.hex()[:14]}-{now.strftime('%Y%m%d%H%M%S')}"


def _load_contract_schema(schema_path: str) -> Optional[Dict[Any, Any]]:
    if not os.path.isdir(schema_path):
        return None

    schema = {}
    for filename in os.listdir(schema_path):
        if filename.endswith(".json"):
            msg_name = os.path.splitext(os.path.basename(filename))[0]
            full_path = os.path.join(schema_path, filename)
            with open(full_path, "r", encoding="utf-8") as msg_schema_file:
                msg_schema = json.load(msg_schema_file)
            schema[msg_name] = msg_schema
    return schema


class LedgerContract(UserString):
    """Ledger contract."""

    def __init__(
        self,
        path: Optional[str],
        client: NeurionClient,
        address: Optional[Address] = None,
        digest: Optional[bytes] = None,
        schema_path: Optional[str] = None,
        code_id: Optional[int] = None,
    ):
        """Initialize the Ledger contract.

        :param path: Path
        :param client: Ledger client
        :param address: address, defaults to None
        :param digest: digest, defaults to None
        :param schema_path: path to contract schema, defaults to None
        :param code_id: optional int. code id of the contract stored
        """
        # pylint: disable=super-init-not-called
        self._path = path
        self._client = client
        self._address = address

        # load contract schema if path is provided
        self._load_schema(schema_path)

        # select the digest either by computing it from the provided contract or by the value specified by
        # the user
        self._digest: Optional[bytes] = digest
        if path is not None:
            self._digest = _compute_digest(str(self._path))

        # attempt to look up the code id from the network by digest
        if not code_id and self._digest is not None:
            self._code_id = self._find_contract_id_by_digest(self._digest)
        else:
            self._code_id = code_id

    @property
    def path(self) -> Optional[str]:
        """Get contract path.

        :return: contract path
        """
        return self._path

    @property
    def digest(self) -> Optional[bytes]:
        """Get the contract digest.

        :return: contract digest
        """
        return self._digest

    @property
    def code_id(self) -> Optional[int]:
        """Get the code id.

        :return: code id
        """
        return self._code_id

    @property
    def address(self) -> Optional[Address]:
        """Get the contract address.

        :return: contract address
        """
        return self._address

    def store(
        self,
        sender: Wallet,
        gas_limit: Optional[int] = None,
        memo: Optional[str] = None,
    ) -> int:
        """Store the contract.

        :param sender: sender wallet address
        :param gas_limit: transaction gas limit, defaults to None
        :param memo: transaction memo, defaults to None
        :raises RuntimeError: Runtime error
        :return: code id
        """
        if self._path is None:
            raise RuntimeError("Unable to upload code, no contract provided")

        # build up the store transaction
        tx = Transaction()
        tx.add_message(create_cosmwasm_store_code_msg(self._path, sender.address()))

        submitted_tx = prepare_and_broadcast_basic_transaction(
            self._client, tx, sender, gas_limit=gas_limit, memo=memo
        ).wait_to_complete()

        # extract the code id
        self._code_id = submitted_tx.contract_code_id
        if self._code_id is None:
            raise RuntimeError("Unable to extract contract code id")

        return self._code_id

    def instantiate(
        self,
        args: Any,
        sender: Wallet,
        label: Optional[str] = None,
        gas_limit: Optional[int] = None,
        admin_address: Optional[Address] = None,
        funds: Optional[str] = None,
    ) -> Address:
        """Instantiate the contract.

        :param args: args
        :param sender: sender wallet address
        :param label: label, defaults to None
        :param gas_limit: transaction gas limit, defaults to None
        :param admin_address: admin address, defaults to None
        :param funds: funds, defaults to None
        :raises RuntimeError: Unable to extract contract code id

        :return: contract address
        """
        assert self._code_id, RuntimeError("Code id was not set.")

        if self._instantiate_schema is not None:
            validate(args, self._instantiate_schema)

        if label is None:
            if self._digest:
                label = _generate_label(bytes(self._digest))
            elif self._code_id:
                label = _generate_label(bytes(f"{self._code_id}", encoding="utf-8"))
            else:
                raise RuntimeError(
                    "Failed to get label. No code_id or digest provided."
                )

        # build up the store transaction
        instatiate_msg = create_cosmwasm_instantiate_msg(
            self._code_id,
            args,
            label,
            sender.address(),
            admin_address=admin_address,
            funds=funds,
        )
        tx = Transaction()
        tx.add_message(instatiate_msg)

        submitted_tx = prepare_and_broadcast_basic_transaction(
            self._client, tx, sender, gas_limit=gas_limit
        ).wait_to_complete()

        # store the contract address
        self._address = submitted_tx.contract_address
        if self._address is None:
            raise RuntimeError("Unable to extract contract code id")

        return self._address

    def upgrade(
        self,
        args: Any,
        sender: Wallet,
        new_path: str,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Store new contract code and migrate the current contract address.

        :param args: args
        :param sender: sender wallet address
        :param new_path: path to new contract
        :param gas_limit: transaction gas limit, defaults to None

        :return: transaction details broadcast
        """
        assert self._address, RuntimeError("Address was not set.")

        if self._migrate_schema is not None:
            validate(args, self._migrate_schema)

        self._path = new_path
        new_code_id = self.store(sender, gas_limit)

        return self.migrate(args, sender, new_code_id, gas_limit)

    def migrate(
        self,
        args: Any,
        sender: Wallet,
        new_code_id: int,
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Migrate the current contract address to new code id.

        :param args: args
        :param sender: sender wallet address
        :param new_code_id: Code id of the newly deployed contract
        :param gas_limit: transaction gas limit, defaults to None

        :return: transaction details broadcast
        """
        assert self._address, RuntimeError("Address was not set.")

        if self._migrate_schema is not None:
            validate(args, self._migrate_schema)

        # build up the migrate transaction
        migrate_msg = create_cosmwasm_migrate_msg(
            new_code_id,
            args,
            self._address,
            sender.address(),
        )
        tx = Transaction()
        tx.add_message(migrate_msg)

        return prepare_and_broadcast_basic_transaction(
            self._client, tx, sender, gas_limit=gas_limit
        ).wait_to_complete()

    def update_admin(
        self,
        sender: Wallet,
        new_admin: Optional[Address],
        gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Update/clear the admin of the contract.

        :param sender: sender wallet address
        :param new_admin: New admin address, None for clear admin
        :param gas_limit: transaction gas limit, defaults to None

        :return: transaction details broadcast
        """
        assert self._address, RuntimeError("Address was not set.")

        # build up the update/clear admin transaction
        if new_admin is None:
            msg = create_cosmwasm_clear_admin_msg(
                sender.address(),
                self._address,
            )
        else:
            msg = create_cosmwasm_update_admin_msg(
                sender.address(), self._address, new_admin
            )

        tx = Transaction()
        tx.add_message(msg)

        return prepare_and_broadcast_basic_transaction(
            self._client, tx, sender, gas_limit=gas_limit
        ).wait_to_complete()

    def deploy(
        self,
        args: Any,
        sender: Wallet,
        label: Optional[str] = None,
        store_gas_limit: Optional[int] = None,
        instantiate_gas_limit: Optional[int] = None,
        admin_address: Optional[Address] = None,
        funds: Optional[str] = None,
    ) -> Address:
        """Deploy the contract.

        :param args: args
        :param sender: sender address
        :param label: label, defaults to None
        :param store_gas_limit: store gas limit, defaults to None
        :param instantiate_gas_limit: instantiate gas limit, defaults to None
        :param admin_address: admin address, defaults to None
        :param funds: funds, defaults to None
        :return: instantiate contract details
        """
        # in the case where the contract is already deployed
        if self._address is not None and self._code_id is not None:
            return self._address

        assert self._address is None

        if self._code_id is None:
            self.store(sender, gas_limit=store_gas_limit)

        assert self._code_id is not None

        return self.instantiate(
            args,
            sender,
            label=label,
            gas_limit=instantiate_gas_limit,
            admin_address=admin_address,
            funds=funds,
        )

    def execute(
        self,
        args: Any,
        sender: Wallet,
        gas_limit: Optional[int] = None,
        funds: Optional[str] = None,
    ) -> SubmittedTx:
        """execute the contract.

        :param args: args
        :param sender: sender address
        :param gas_limit: transaction gas limit, defaults to None
        :param funds: funds, defaults to None
        :raises RuntimeError: Contract appears not to be deployed currently
        :return: transaction details broadcast
        """
        if self._address is None:
            raise RuntimeError("Contract appears not to be deployed currently")

        if self._execute_schema is not None:
            validate(args, self._execute_schema)

        # build up the execute transaction
        tx = Transaction()
        tx.add_message(
            create_cosmwasm_execute_msg(
                sender.address(), self._address, args, funds=funds
            )
        )

        return prepare_and_broadcast_basic_transaction(
            self._client, tx, sender, gas_limit=gas_limit
        )

    def query(self, args: Any) -> Any:
        """Query on contract.

        :param args: args
        :raises RuntimeError: Contract appears not to be deployed currently
        :return: query result
        """
        if self._address is None:
            raise RuntimeError("Contract appears not to be deployed currently")

        if self._query_schema is not None:
            validate(args, self._query_schema)

        req = QuerySmartContractStateRequest(
            address=str(self._address), query_data=json_encode(args).encode("UTF8")
        )
        resp = self._client.wasm.SmartContractState(req)
        return json.loads(resp.data)

    def _find_contract_id_by_digest(self, digest: bytes) -> Optional[int]:
        code_id = None

        pagination = None
        while True:
            req = QueryCodesRequest(pagination=pagination)
            resp = self._client.wasm.Codes(req)
            for code_info in resp.code_infos:
                if code_info.data_hash == digest:
                    code_id = int(code_info.code_id)
                    break

            # exit the search loop if we have successfully found our code id
            if code_id is not None:
                break

            # exit the search loop when we can't iterate any further
            if len(resp.pagination.next_key) == 0:
                break

            # proceed to the next page
            pagination = PageRequest(key=resp.pagination.next_key)

        return code_id

    def _load_schema(self, schema_path: Optional[str]):
        self._schema: Optional[Dict[str, Any]] = None
        self._instantiate_schema: Optional[Dict[str, Any]] = None
        self._query_schema: Optional[Dict[str, Any]] = None
        self._execute_schema: Optional[Dict[str, Any]] = None
        self._migrate_schema: Optional[Dict[str, Any]] = None

        if schema_path is None:
            return

        self._schema = _load_contract_schema(schema_path)
        if self._schema is None:
            return

        for msg_type, schema in self._schema.items():
            if "instantiate" in msg_type:
                self._instantiate_schema = schema
            elif "query" in msg_type:
                self._query_schema = schema
            elif "execute" in msg_type:
                self._execute_schema = schema
            elif "migrate" in msg_type:
                self._migrate_schema = schema

    @property
    def data(self):
        """Get the contract address.

        :return: contract address
        """
        return self.address

    def __json__(self):
        """Get the contract details in json.

        :return: contract details in json
        """
        return str(self)
